@@ -1,6 +1,6 @@
 
 ##
-##  Copyright (C) 2015  Whit Armstrong and Dirk Eddelbuettel and John Laing
+##  Copyright (C) 2015 - 2016  Whit Armstrong and Dirk Eddelbuettel and John Laing
 ##
 ##  This file is part of Rblpapi
 ##
@@ -31,11 +31,13 @@
 ##' @param overrides An optional named character vector with override
 ##' values. Each field must have both a name (designating the override
 ##' being set) as well as a value.
+##' @param verbose A boolean indicating whether verbose operation is
+##' desired, defaults to \sQuote{FALSE}
 ##' @param identity An optional identity object.
 ##' @param con A connection object as created by a \code{blpConnect}
 ##' call, and retrieved via the internal function
 ##' \code{defaultConnection}.
-##' @return A list with as a entries as there are entries in
+##' @return A list with as many entries as there are entries in
 ##' \code{securities}; each list contains a data.frame with one row
 ##' per observations and as many columns as entries in
 ##' \code{fields}. If the list is of length one, it is collapsed into
@@ -43,12 +45,17 @@
 ##' @author Whit Armstrong and Dirk Eddelbuettel
 ##' @examples
 ##' \dontrun{
+##'   ## simple query
 ##'   bds("GOOG US Equity", "TOP_20_HOLDERS_PUBLIC_FILINGS")
+##'   ## example of using overrides
+##'   overrd <- c("START_DT"="20150101", "END_DT"="20160101")
+##    bds("CPI YOY Index","ECO_RELEASE_DT_LIST", overrides = overrd)
 ##' }
 bds <- function(securities, fields, options=NULL,
-                overrides=NULL, identity=NULL, con=defaultConnection()) {
+                overrides=NULL, verbose=FALSE,
+                identity=NULL, con=defaultConnection()) {
     if (length(securities)!=1L) stop("more than one security submitted.", call.=FALSE)
-    res <- bds_Impl(con, securities, fields, options, overrides, identity)
+    res <- bds_Impl(con, securities, fields, options, overrides, verbose, identity)
     if (typeof(res)=="list" && length(res)==1) {
         res <- res[[1]]
     }
