@@ -32,7 +32,7 @@
 ##' desired, defaults to \sQuote{FALSE}
 ##' @param returnAs A character variable describing the type of return
 ##' object; currently supported are \sQuote{matrix} (also the default),
-##' \sQuote{fts}, \sQuote{xts} and \sQuote{zoo}  
+##' \sQuote{fts}, \sQuote{xts} and \sQuote{zoo}
 ##' @param tz A character variable with the desired local timezone,
 ##' defaulting to the value \sQuote{TZ} environment variable, and
 ##' \sQuote{UTC} if unset
@@ -43,6 +43,10 @@
 ##' \sQuote{POSIXct} object), \sQuote{values} and \sQuote{sizes}, or
 ##' an object of the type selected in \code{returnAs}.
 ##' @author Dirk Eddelbuettel
+##' @examples
+##' \dontrun{
+##'   getTicks("ES1 Index")
+##' }
 getTicks <- function(security,
                      eventType = "TRADE",
                      startTime = Sys.time()-60*60,
@@ -52,6 +56,9 @@ getTicks <- function(security,
                      tz = Sys.getenv("TZ", unset="UTC"),
                      con = defaultConnection()) {
 
+    if (!inherits(startTime, "POSIXt") || !inherits(endTime, "POSIXt")) {
+        stop("startTime and endTime must be Datetime objects", call.=FALSE)
+    }
     fmt <- "%Y-%m-%dT%H:%M:%S"
     startUTC <- format(startTime, fmt, tz="UTC")
     endUTC <- format(endTime, fmt, tz="UTC")
@@ -68,16 +75,6 @@ getTicks <- function(security,
                   res)                         # fallback is also matrix
     return(res)   # to return visibly
 
-    ## commented out option
-    
-    ##' @param setCondCodes A boolean indicating whether to return any
-    ##' ticks with condition codes, associated with extraordinary trading
-    ##' and quoting circumstances, defaults to \sQuote{FALSE}. This is
-    ##' similar to setting \code{CondCodes = S} and \code{QRM = S} in
-    ##' Excel API
-
-    ##  setCondCodes = FALSE,
-
 }
 
 ##' This function uses the Bloomberg API to retrieve multiple ticks
@@ -141,11 +138,11 @@ getMultipleTicks <- function(security,
         ## Use na.locf to carry bid, ask, .. forward, but do not use trade column
         ind <- !grepl("trade", colnames(x))
         x[,ind] <- zoo::na.locf(x[,ind])
-        
+
         zoo::index(x) <- trunc(zoo::index(x)) # truncated time stamp down to seconds
         return(x)
-    } 
-        
+    }
+
     return(res)
 
 }
